"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.run = void 0;
const child_process_1 = __importDefault(require("child_process"));
const os_1 = __importDefault(require("os"));
function spawnAsync(cmd, args) {
    return new Promise(function (resolve) {
        const proc = child_process_1.default.spawn(cmd, args);
        proc.stdout.on('data', (data) => {
            process.stdout.write(data.toString());
        });
        proc.stderr.on('data', (data) => {
            process.stderr.write(data.toString());
        });
        proc.on('exit', function (exitCode) {
            resolve(exitCode);
        });
        proc.on('error', function (err) {
            console.log(`Unable to start command: ${err}`);
            resolve(1);
        });
    });
}
async function preExecRunner(preExecs) {
    const cmdInvoker = (os_1.default.platform() === 'win32') ? 'cmd' : 'sh';
    const cmdArg = (os_1.default.platform() === 'win32') ? '/C' : '-c';
    for (const command of preExecs) {
        console.log(`Executing pre-exec command: ${command}`);
        const exitCode = await spawnAsync(cmdInvoker, [cmdArg, command]);
        console.log('\n');
        if (exitCode !== 0) {
            return false;
        }
    }
    return true;
}
async function run(suite, timeoutSec) {
    if (!suite.preExec) {
        return true;
    }
    let timeout;
    const timeoutPromise = new Promise((resolve) => {
        timeout = setTimeout(() => {
            console.error(`Pre-Exec timed out after ${timeoutSec} seconds`);
            resolve(false);
        }, timeoutSec * 1000);
    });
    const hasPassed = await Promise.race([timeoutPromise, preExecRunner(suite.preExec)]);
    clearTimeout(timeout);
    return hasPassed;
}
exports.run = run;
exports.default = run;
//# sourceMappingURL=preExec.js.map